@@ -14,6 +14,13 @@ from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
 
+from .appstore.auth import (
+    AppStoreAuth,
+    AppStoreAuthError,
+    AppStoreCredentials,
+    create_config_file,
+)
+from .appstore.uploader import ScreenshotUploader, ScreenshotUploadError
 from .config import ProjectConfig
 from .exceptions import KoubouError
 from .generator import ScreenshotGenerator
@@ -313,6 +320,74 @@ def generate(
         raise typer.Exit(1)
 
 
+@app.command()
+def list_frames(
+    search: Optional[str] = typer.Argument(None, help="Filter frames by search term"),
+    verbose: bool = typer.Option(False, "--verbose", help="Enable verbose logging"),
+):
+    """📱 List all available device frame names with optional fuzzy search"""
+    setup_logging(verbose)
+
+    try:
+        # Initialize generator to access device frame renderer
+        generator = ScreenshotGenerator()
+
+        # Get all available frames
+        all_frames = generator.device_frame_renderer.get_available_frames()
+
+        if not all_frames:
+            console.print("❌ No device frames found", style="red")
+            raise typer.Exit(1)
+
+        # Apply search filter if provided
+        if search:
+            filtered_frames = [
+                frame for frame in all_frames if search.lower() in frame.lower()
+            ]
+            frames_to_display = filtered_frames
+
+            if not filtered_frames:
+                console.print(f"❌ No frames found matching '{search}'", style="red")
+                return  # Exit normally without showing table
+
+            console.print(
+                f"📱 Found {len(filtered_frames)} frames matching '{search}'",
+                style="green",
+            )
+        else:
+            frames_to_display = all_frames
+            console.print(
+                f"📱 Found {len(all_frames)} available device frames", style="green"
+            )
+
+        # Create and display results table
+        table = Table(
+            title="🎯 Available Device Frames",
+            show_header=True,
+            header_style="bold magenta",
+        )
+        table.add_column("Frame Name", style="cyan", no_wrap=False)
+
+        # Add frames to table
+        for frame_name in frames_to_display:
+            table.add_row(frame_name)
+
+        console.print(table)
+
+        # Show usage tip
+        if not search:
+            console.print(
+                "\n💡 Tip: Use 'kou list-frames iPhone' to filter by device type",
+                style="blue",
+            )
+
+    except Exception as e:
+        console.print(f"❌ Error listing frames: {e}", style="red")
+        if verbose:
+            console.print_exception()
+        raise typer.Exit(1)
+
+
 @app.command()
 def live(
     config_file: Path = typer.Argument(..., help="YAML configuration file to watch"),
@@ -471,6 +546,241 @@ def _update_live_status(
     status_display.renderable = status_text
 
 
+@app.command()
+def upload(
+    config_file: Path = typer.Argument(..., help="YAML configuration file"),
+    setup: bool = typer.Option(
+        False, "--setup", help="Setup App Store Connect credentials only"
+    ),
+    dry_run: bool = typer.Option(
+        False, "--dry-run", help="Preview upload without actually uploading"
+    ),
+    verbose: bool = typer.Option(False, "--verbose", help="Enable verbose logging"),
+):
+    """📱 Upload generated screenshots to App Store Connect"""
+
+    setup_logging(verbose)
+
+    try:
+        # Validate config file exists
+        if not config_file.exists():
+            console.print(
+                f"❌ Configuration file not found: {config_file}", style="red"
+            )
+            raise typer.Exit(1)
+
+        # Determine App Store config path (next to YAML config)
+        appstore_config_path = config_file.parent / "appstore-config.json"
+
+        # Handle setup-only mode
+        if setup:
+            _setup_appstore_credentials(appstore_config_path)
+            raise typer.Exit(0)
+
+        # Check for existing App Store config
+        if not appstore_config_path.exists():
+            console.print(
+                f"❌ App Store Connect config not found: {appstore_config_path.name}",
+                style="red",
+            )
+
+            # Ask user if they want to create it
+            create_config = typer.confirm("? Would you like to create it now?")
+            if create_config:
+                _setup_appstore_credentials(appstore_config_path)
+                console.print(
+                    "\nℹ️ Setup complete! Run the upload command again to upload screenshots.",
+                    style="blue",
+                )
+                raise typer.Exit(0)
+            else:
+                console.print("💡 You can create the config later with:", style="blue")
+                console.print(f"   kou upload --setup {config_file}", style="cyan")
+                raise typer.Exit(1)
+
+        # Load App Store credentials
+        try:
+            credentials = AppStoreCredentials.from_config_file(appstore_config_path)
+            console.print("✅ Loaded App Store Connect credentials", style="green")
+        except AppStoreAuthError as e:
+            console.print(f"❌ Invalid App Store Connect config: {e}", style="red")
+            console.print("💡 Fix the config or recreate it with:", style="blue")
+            console.print(f"   kou upload --setup {config_file}", style="cyan")
+            raise typer.Exit(1)
+
+        # Validate credentials by generating a test token
+        try:
+            auth = AppStoreAuth(credentials)
+            auth.validate_credentials()
+            console.print("✅ App Store Connect credentials validated", style="green")
+        except AppStoreAuthError as e:
+            console.print(f"❌ Credential validation failed: {e}", style="red")
+            raise typer.Exit(1)
+
+        # Find generated screenshots directory
+        with open(config_file) as f:
+            config_data = yaml.safe_load(f)
+
+        project_config = ProjectConfig(**config_data)
+        screenshots_dir = Path(config_file.parent) / project_config.project.output_dir
+
+        if not screenshots_dir.exists():
+            console.print(
+                f"❌ Screenshots directory not found: {screenshots_dir}", style="red"
+            )
+            console.print("💡 Generate screenshots first with:", style="blue")
+            console.print(f"   kou {config_file}", style="cyan")
+            raise typer.Exit(1)
+
+        # Initialize uploader and analyze screenshots
+        uploader = ScreenshotUploader(credentials)
+
+        try:
+            console.print("🔍 Analyzing generated screenshots...", style="blue")
+            screenshot_infos = uploader.analyze_screenshots(screenshots_dir)
+
+            console.print(
+                f"✅ Found {len(screenshot_infos)} valid screenshots", style="green"
+            )
+
+            # Show preview of what will be uploaded
+            _show_upload_preview(screenshot_infos)
+
+            if dry_run:
+                console.print(
+                    "\n🧪 Dry run complete - no screenshots were uploaded",
+                    style="yellow",
+                )
+                raise typer.Exit(0)
+
+            # Confirm upload
+            if not typer.confirm("\n? Proceed with upload?"):
+                console.print("Upload cancelled", style="yellow")
+                raise typer.Exit(0)
+
+            # Perform upload
+            console.print("\n🚀 Starting upload to App Store Connect...", style="blue")
+            results = uploader.upload_screenshots(screenshot_infos)
+
+            # Show results
+            _show_upload_results(results)
+
+            # Exit with appropriate code
+            failed_count = sum(1 for r in results if not r.success)
+            if failed_count > 0:
+                console.print(
+                    f"\n⚠️ {failed_count} screenshot(s) failed to upload", style="yellow"
+                )
+                raise typer.Exit(1)
+
+            console.print(
+                f"\n✅ Successfully uploaded {len(results)} screenshots!", style="green"
+            )
+
+        except ScreenshotUploadError as e:
+            console.print(f"❌ Upload failed: {e}", style="red")
+            raise typer.Exit(1)
+
+    except KoubouError as e:
+        console.print(f"❌ {e}", style="red")
+        raise typer.Exit(1)
+    except Exception as e:
+        console.print(f"❌ Unexpected error: {e}", style="red")
+        if verbose:
+            console.print_exception()
+        raise typer.Exit(1)
+
+
+def _setup_appstore_credentials(config_path: Path) -> None:
+    """Interactive setup of App Store Connect credentials."""
+    console.print("📝 Setting up App Store Connect integration...", style="blue")
+
+    # Collect credentials interactively
+    key_id = typer.prompt("? Key ID (from App Store Connect)")
+    issuer_id = typer.prompt("? Issuer ID (from App Store Connect)")
+    private_key_path = typer.prompt(
+        "? Private key file path", default="./AuthKey_" + key_id + ".p8"
+    )
+    app_id = typer.prompt("? App ID (from App Store Connect)")
+
+    # Validate private key file exists
+    key_path = Path(private_key_path).expanduser()
+    if not key_path.is_absolute():
+        key_path = config_path.parent / key_path
+
+    if not key_path.exists():
+        console.print(f"❌ Private key file not found: {key_path}", style="red")
+        raise typer.Exit(1)
+
+    # Create config
+    credentials_data = {
+        "key_id": key_id,
+        "issuer_id": issuer_id,
+        "private_key_path": private_key_path,
+        "app_id": app_id,
+    }
+
+    try:
+        create_config_file(config_path, credentials_data)
+        console.print(f"✅ Created {config_path.name}", style="green")
+
+        # Test credentials
+        credentials = AppStoreCredentials.from_config_file(config_path)
+        auth = AppStoreAuth(credentials)
+        auth.validate_credentials()
+        console.print("✅ Credentials validated successfully", style="green")
+
+    except (AppStoreAuthError, Exception) as e:
+        console.print(f"❌ Setup failed: {e}", style="red")
+        # Clean up failed config file
+        if config_path.exists():
+            config_path.unlink()
+        raise typer.Exit(1)
+
+
+def _show_upload_preview(screenshot_infos) -> None:
+    """Show preview of screenshots to be uploaded."""
+    table = Table(
+        title="📤 Upload Preview", show_header=True, header_style="bold magenta"
+    )
+    table.add_column("Screenshot", style="cyan")
+    table.add_column("Device Type", style="green")
+    table.add_column("App Store Type", style="blue")
+    table.add_column("Size", style="yellow")
+
+    for info in screenshot_infos:
+        table.add_row(
+            info.path.name,
+            info.device_type,
+            info.display_type,
+            f"{info.size[0]}×{info.size[1]}",
+        )
+
+    console.print(table)
+
+
+def _show_upload_results(results) -> None:
+    """Show upload results in a table."""
+    table = Table(
+        title="📱 Upload Results", show_header=True, header_style="bold magenta"
+    )
+    table.add_column("Screenshot", style="cyan")
+    table.add_column("Status", style="green")
+    table.add_column("Details", style="blue")
+
+    for result in results:
+        if result.success:
+            status = "✅ Success"
+            details = result.screenshot_id or "Uploaded"
+        else:
+            status = "❌ Failed"
+            details = result.error_message or "Unknown error"
+
+        table.add_row(result.screenshot_path.name, status, details)
+
+    console.print(table)
+
+
 def main() -> None:
     """Main entry point."""
     app()
