@@ -9,6 +9,7 @@ from PIL import Image
 
 from .config import GradientConfig, ProjectConfig, ScreenshotConfig, TextOverlay
 from .exceptions import ConfigurationError, RenderError
+from .localization import LocalizedContentResolver, XCStringsManager
 from .renderers.background import BackgroundRenderer
 from .renderers.device_frame import DeviceFrameRenderer
 from .renderers.text import TextRenderer
@@ -82,10 +83,6 @@ class ScreenshotGenerator:
         try:
             logger.info(f"🎬 Starting generation: {config.name}")
 
-            # Load source image
-            source_image = self._load_source_image(config.source_image)
-            logger.info(f"📷 Loaded source: {source_image.size}")
-
             # Create canvas at target size
             canvas = Image.new("RGBA", config.output_size, (255, 255, 255, 0))
             logger.info(f"🎨 Created canvas: {config.output_size}")
@@ -95,18 +92,61 @@ class ScreenshotGenerator:
                 logger.info(f"🌈 Rendering background: {config.background.type}")
                 self.background_renderer.render(config.background, canvas)
 
-            # Position and composite source image with optional frame
-            logger.info("📐 Positioning source image")
-            positioned_image = self._position_source_image(source_image, canvas, config)
+            # Process multiple images if available, otherwise use single image
+            # (backward compatibility)
+            if hasattr(config, "_image_configs") and config._image_configs:
+                logger.info(
+                    f"📷 Processing {len(config._image_configs)} images in layer order"
+                )
+                # Process images in YAML order (first = bottom layer, last = top layer)
+                for i, img_config in enumerate(config._image_configs):
+                    logger.info(
+                        f"📐 Layer {i+1}/{len(config._image_configs)}: "
+                        f"{Path(img_config['path']).name}"
+                    )
 
-            # Apply device frame to individual image if frame: true
-            if config.image_frame and config.device_frame:
-                logger.info(f"📱 Applying device frame to asset: {config.device_frame}")
-                positioned_image = self._apply_asset_frame(
-                    positioned_image, canvas, config
+                    # Load and position each image
+                    source_image = self._load_source_image(img_config["path"])
+                    logger.info(f"📷 Loaded source: {source_image.size}")
+
+                    # Create temporary config for this image
+                    temp_config = self._create_temp_config_for_image(config, img_config)
+                    positioned_image = self._position_source_image(
+                        source_image, canvas, temp_config
+                    )
+
+                    # Apply device frame if specified for this image
+                    if img_config["frame"] and config.device_frame:
+                        logger.info(
+                            f"📱 Applying device frame to asset: {config.device_frame}"
+                        )
+                        positioned_image = self._apply_asset_frame(
+                            positioned_image, canvas, temp_config
+                        )
+
+                    # Composite this layer onto canvas
+                    canvas = Image.alpha_composite(canvas, positioned_image)
+            else:
+                # Backward compatibility: single image processing
+                logger.info("📷 Processing single image (legacy mode)")
+                source_image = self._load_source_image(config.source_image)
+                logger.info(f"📷 Loaded source: {source_image.size}")
+
+                logger.info("📐 Positioning source image")
+                positioned_image = self._position_source_image(
+                    source_image, canvas, config
                 )
 
-            canvas = Image.alpha_composite(canvas, positioned_image)
+                # Apply device frame to individual image if frame: true
+                if config.image_frame and config.device_frame:
+                    logger.info(
+                        f"📱 Applying device frame to asset: {config.device_frame}"
+                    )
+                    positioned_image = self._apply_asset_frame(
+                        positioned_image, canvas, config
+                    )
+
+                canvas = Image.alpha_composite(canvas, positioned_image)
 
             # Render text overlays
             if config.text_overlays:
@@ -174,6 +214,18 @@ class ScreenshotGenerator:
                 (scaled_width, scaled_height), Image.Resampling.LANCZOS
             )
 
+        # Apply rotation if specified
+        rotation_angle = getattr(config, "image_rotation", 0) or 0
+        if rotation_angle != 0:
+            logger.info(f"🔄 Rotating image by {rotation_angle}°")
+            source_image = source_image.rotate(
+                -rotation_angle,  # Negative for clockwise rotation (PIL uses counter-clockwise)
+                resample=Image.Resampling.BICUBIC,  # Use BICUBIC instead of LANCZOS for compatibility
+                expand=True,  # Expand bounds to prevent cropping
+            )
+            # Update dimensions after rotation
+            scaled_width, scaled_height = source_image.size
+
         # Position image at % coordinates relative to canvas
         position = config.image_position or ["50%", "50%"]
         x_percent, y_percent = position
@@ -197,6 +249,24 @@ class ScreenshotGenerator:
 
         return positioned
 
+    def _create_temp_config_for_image(
+        self, base_config: ScreenshotConfig, img_config: dict
+    ):
+        """Create a temporary config for individual image processing."""
+
+        # Create a copy of the base config with image-specific settings
+        class TempConfig:
+            def __init__(self, base, img):
+                self.name = base.name
+                self.device_frame = base.device_frame
+                self.output_size = base.output_size
+                self.image_position = img["position"]
+                self.image_scale = img["scale"]
+                self.image_frame = img["frame"]
+                self.image_rotation = img.get("rotation", 0)
+
+        return TempConfig(base_config, img_config)
+
     def _convert_percentage_to_pixels(self, percentage_str: str, dimension: int) -> int:
         """Convert percentage string to pixel position."""
         if percentage_str.endswith("%"):
@@ -225,7 +295,8 @@ class ScreenshotGenerator:
             else:
                 # Size mismatch - need to handle this case
                 logger.warning(
-                    "Canvas size {canvas.size} doesn't match frame size {frame_image.size}"
+                    f"Canvas size {canvas.size} doesn't match frame size "
+                    f"{frame_image.size}"
                 )
                 # For now, resize canvas to match frame
                 resized_canvas = canvas.resize(
@@ -261,10 +332,12 @@ class ScreenshotGenerator:
             )
 
             logger.info(
-                "📱 Scaled frame: {original_frame_size} → {scaled_frame.size} (scale: {asset_scale})"
+                f"📱 Scaled frame: {original_frame_size} → {scaled_frame.size} "
+                f"(scale: {asset_scale})"
             )
 
-            # Generate screen mask from the already-scaled frame (preserves precise boundaries)
+            # Generate screen mask from the already-scaled frame
+            # (preserves precise boundaries)
             screen_mask = self.device_frame_renderer.generate_screen_mask_from_image(
                 scaled_frame
             )
@@ -280,7 +353,8 @@ class ScreenshotGenerator:
             frame_y = center_y - scaled_frame_height // 2
 
             logger.info(
-                "📱 Positioning frame: center at ({center_x}, {center_y}), top-left at ({frame_x}, {frame_y})"
+                f"📱 Positioning frame: center at ({center_x}, {center_y}), "
+                f"top-left at ({frame_x}, {frame_y})"
             )
 
             # Step 1: Start with the positioned asset (no masking yet)
@@ -333,7 +407,8 @@ class ScreenshotGenerator:
 
         Args:
             project_config: Complete project configuration
-            config_dir: Directory containing the config file (for relative path resolution)
+            config_dir: Directory containing the config file (for relative path
+                resolution)
 
         Returns:
             List of paths to generated screenshots
@@ -342,6 +417,18 @@ class ScreenshotGenerator:
         logger.info(f"📁 Output directory: {project_config.project.output_dir}")
         logger.info(f"🎯 Screenshots to generate: {len(project_config.screenshots)}")
 
+        # Check if localization is enabled
+        if project_config.localization:
+            return self._generate_localized_project(project_config, config_dir)
+        else:
+            return self._generate_single_language_project(project_config, config_dir)
+
+    def _generate_single_language_project(
+        self, project_config: ProjectConfig, config_dir: Optional[Path] = None
+    ) -> List[Path]:
+        """Generate screenshots for single language (original behavior)."""
+        logger.info("🌍 Single language mode")
+
         # Get defaults and devices
         defaults = project_config.defaults or {}
         default_background = defaults.get("background")
@@ -374,10 +461,119 @@ class ScreenshotGenerator:
                 continue
 
         logger.info(
-            "🎉 Project complete! Generated {len(results)}/{len(project_config.screenshots)} screenshots"
+            f"🎉 Project complete! Generated {len(results)}/"
+            f"{len(project_config.screenshots)} screenshots"
         )
         return results
 
+    def _generate_localized_project(
+        self, project_config: ProjectConfig, config_dir: Optional[Path] = None
+    ) -> List[Path]:
+        """Generate screenshots for all configured languages."""
+        localization_config = project_config.localization
+        logger.info(
+            f"🌍 Multi-language mode: {len(localization_config.languages)} languages"
+        )
+        logger.info(f"📝 Languages: {', '.join(localization_config.languages)}")
+
+        # Initialize localization components
+        if not config_dir:
+            config_dir = Path.cwd()
+
+        xcstrings_manager = XCStringsManager(localization_config, config_dir)
+        content_resolver = LocalizedContentResolver(xcstrings_manager)
+
+        # Extract all text keys from all screenshots
+        all_text_keys = set()
+        for screenshot_def in project_config.screenshots.values():
+            text_keys = content_resolver.extract_text_keys_from_content(
+                screenshot_def.content
+            )
+            all_text_keys.update(text_keys)
+
+        logger.info(f"🔤 Found {len(all_text_keys)} unique text keys")
+
+        # Create or update xcstrings file
+        if not xcstrings_manager.xcstrings_exists():
+            logger.info("📝 Creating XCStrings file")
+            xcstrings_manager.create_xcstrings_file(all_text_keys)
+        else:
+            logger.info("📝 Updating XCStrings file with new keys")
+            xcstrings_manager.update_xcstrings_with_new_keys(all_text_keys)
+
+        # Get defaults and devices
+        defaults = project_config.defaults or {}
+        default_background = defaults.get("background")
+        device_frame = None
+        if project_config.devices:
+            device_frame = self._map_device_name(project_config.devices[0])
+
+        all_results = []
+
+        # Generate screenshots for each language
+        for language in localization_config.languages:
+            logger.info(f"🌐 Generating screenshots for language: {language}")
+
+            for i, (screenshot_id, screenshot_def) in enumerate(
+                project_config.screenshots.items(), 1
+            ):
+                logger.info(
+                    f"[{language}] [{i}/{len(project_config.screenshots)}] "
+                    f"{screenshot_id}"
+                )
+                try:
+                    # Create localized content
+                    localized_content = content_resolver.localize_content_items(
+                        screenshot_def.content, language
+                    )
+
+                    # Create a copy of screenshot definition with localized content
+                    from copy import deepcopy
+
+                    localized_screenshot_def = deepcopy(screenshot_def)
+                    localized_screenshot_def.content = localized_content
+
+                    # Generate language-specific output directory
+                    language_output_dir = str(
+                        Path(project_config.project.output_dir) / language
+                    )
+
+                    if project_config.devices:
+                        device_name = project_config.devices[0].replace(" ", "_")
+                        language_output_dir = str(
+                            Path(language_output_dir) / device_name
+                        )
+
+                    # Convert to ScreenshotConfig and generate
+                    temp_config = self._convert_to_screenshot_config(
+                        localized_screenshot_def,
+                        device_frame,
+                        default_background,
+                        language_output_dir,
+                        config_dir,
+                        screenshot_id,
+                    )
+                    if temp_config:
+                        output_path = self.generate_screenshot(temp_config)
+                        all_results.append(output_path)
+                    else:
+                        logger.warning(
+                            f"Skipping {screenshot_id} for {language}: "
+                            f"no source image found"
+                        )
+                except Exception as _e:
+                    logger.error(
+                        f"Failed to generate {screenshot_id} for {language}: {_e}"
+                    )
+                    # Continue with next screenshot instead of failing entire project
+                    continue
+
+        logger.info(
+            f"🎉 Localized project complete! Generated {len(all_results)} screenshots "
+            f"across {len(localization_config.languages)} languages"
+        )
+        return all_results
+
     def _resolve_output_path(
         self, output_dir: str, screenshot_name: str, config_dir: Optional[Path] = None
     ) -> Path:
@@ -402,66 +598,90 @@ class ScreenshotGenerator:
     ):
         """Convert ScreenshotDefinition to ScreenshotConfig for generation."""
 
-        # Process content items and calculate dimensions
-        source_image_path = None
-        image_scale = 1.0
+        # Process content items and collect ALL images
+        image_configs = []
         text_overlays = []
 
-        # Store image configurations for proper positioning
-        image_config = None
-
+        # Process all content items to collect images and text
         for item in screenshot_def.content:
             if item.type == "image":
                 # Get source image path, scale, and position
                 asset_path = item.asset or ""
-                if asset_path.startswith("../"):
-                    source_image_path = str(
-                        Path("/Users/davidcollado/Projects").resolve() / asset_path[3:]
-                    )
+                if not asset_path:
+                    source_image_path = ""
+                elif Path(asset_path).is_absolute():
+                    source_image_path = asset_path
+                elif config_dir and asset_path:
+                    # Resolve relative paths against config directory
+                    try:
+                        source_image_path = str((config_dir / asset_path).resolve())
+                    except (OSError, ValueError):
+                        source_image_path = asset_path
                 else:
                     source_image_path = asset_path
+
                 image_scale = item.scale or 1.0
                 image_position = item.position or ["50%", "50%"]  # Default to center
 
-                # Store image configuration including frame setting
+                # Store image configuration including frame and rotation settings
+                image_rotation = getattr(item, "rotation", 0) or 0
                 image_config = {
+                    "path": source_image_path,
                     "scale": image_scale,
                     "position": image_position,
                     "frame": getattr(item, "frame", False),  # Capture frame setting
+                    "rotation": image_rotation,  # Capture rotation setting
                 }
+                image_configs.append(image_config)
                 logger.info(
                     f"📏 Image: scale={image_scale * 100:.0f}%, "
-                    f"position={image_position}, frame={getattr(item, 'frame', False)}"
+                    f"position={image_position}, frame={getattr(item, 'frame', False)}, "
+                    f"rotation={image_rotation}°"
                 )
-                break  # Use first image found
+                # Continue processing more images instead of breaking
 
-        # Skip if no source image found
-        if not source_image_path or not Path(source_image_path).exists():
-            logger.warning(
-                f"Source image not found for {screenshot_id}: {source_image_path}"
-            )
+        # Skip if no images found
+        if not image_configs:
+            logger.warning(f"No images found for {screenshot_id}")
             return None
 
-        # Load source image to get actual dimensions
+        # Validate that all image paths exist
+        for img_config in image_configs:
+            if not img_config["path"] or not Path(img_config["path"]).exists():
+                logger.error(f"Source image not found: {img_config['path']}")
+                if not img_config["path"]:
+                    raise ConfigurationError("Image asset path is empty or missing")
+                else:
+                    raise ConfigurationError(
+                        f"Image asset not found: {img_config['path']}"
+                    )
+
+        # Use first image for canvas sizing (backward compatibility)
+        # TODO: Could be enhanced to calculate optimal canvas size from all images
+        primary_image_config = image_configs[0]
         from PIL import Image
 
-        source_image = Image.open(source_image_path)
+        source_image = Image.open(primary_image_config["path"])
         original_width, original_height = source_image.size
+        image_scale = primary_image_config["scale"]
 
         # Calculate scaled image dimensions
         scaled_width = int(original_width * image_scale)
         scaled_height = int(original_height * image_scale)
         logger.info(
-            "📐 Original: {original_width}×{original_height} → Scaled: {scaled_width}×{scaled_height}"
+            f"📐 Original: {original_width}×{original_height} → "
+            f"Scaled: {scaled_width}×{scaled_height}"
         )
 
         # Calculate canvas size - respect screenshot-level frame setting
         # Check frame setting: None=use default, True=force frame, False=no frame
-        frame_setting = getattr(screenshot_def, 'frame', None)
+        frame_setting = getattr(screenshot_def, "frame", None)
         if frame_setting is False:
             should_use_frame = False  # Explicitly disabled
         else:
-            should_use_frame = bool(device_frame)  # Use default logic if frame is None or True
+            should_use_frame = bool(
+                device_frame
+            )  # Use default logic if frame is None or True
         if should_use_frame:
             frame_size = self.device_frame_renderer.get_frame_size(device_frame)
             if frame_size:
@@ -473,7 +693,8 @@ class ScreenshotGenerator:
                 raise ConfigurationError(
                     f"Device frame '{device_frame}' not found. "
                     f"Frame is required when 'frame: true' is specified. "
-                    f"Check available frames or remove 'frame: true' from your configuration."
+                    f"Check available frames or remove 'frame: true' from your "
+                    f"configuration."
                 )
         else:
             # No frame: canvas = scaled image + padding for text
@@ -498,10 +719,12 @@ class ScreenshotGenerator:
                         position=position,
                         font_size=item.size or 24,
                         font_weight=getattr(item, "weight", "normal") or "normal",
-                        color=item.color,  # Don't default to black if gradient is provided
+                        color=item.color,  # Don't default to black if gradient
+                        # is provided
                         gradient=item.gradient,  # Pass gradient configuration
                         alignment=getattr(item, "alignment", "center") or "center",
-                        anchor="center",  # Use center anchor for percentage-based positioning
+                        anchor="center",  # Use center anchor for
+                        # percentage-based positioning
                         max_width=getattr(
                             item, "maxWidth", None
                         ),  # User controls maxWidth, default None means no limit
@@ -514,7 +737,8 @@ class ScreenshotGenerator:
                     )
                     text_overlays.append(text_overlay)
 
-        # Create background config with priority: screenshot background > default background > white
+        # Create background config with priority: screenshot background >
+        # default background > white
         background_config = None
         if screenshot_def.background:
             # Use per-screenshot background if specified
@@ -535,24 +759,24 @@ class ScreenshotGenerator:
             background_config = GradientConfig(type="solid", colors=["#ffffff"])
 
         # Create screenshot config with calculated dimensions
-        # Store scale factor for use during generation
+        # For backward compatibility, use primary image in main config
         config = ScreenshotConfig(
             name=screenshot_id,
-            source_image=source_image_path,
+            source_image=primary_image_config["path"],
             device_frame=device_frame if should_use_frame else None,
             output_size=(canvas_width, canvas_height),  # Dynamic size based on content
             background=background_config,
             text_overlays=text_overlays,
-            image_position=image_config["position"] if image_config else ["50%", "50%"],
-            image_scale=image_config["scale"] if image_config else 1.0,
-            image_frame=image_config["frame"] if image_config else False,
+            image_position=primary_image_config["position"],
+            image_scale=primary_image_config["scale"],
+            image_frame=primary_image_config["frame"],
             output_path=str(
                 self._resolve_output_path(output_dir, screenshot_id, config_dir)
             ),
         )
 
-        # Store scale factor as a custom attribute for positioning
-        config._image_scale = image_scale
+        # Store ALL image configurations as custom attribute for multi-image support
+        config._image_configs = image_configs
         config._scaled_dimensions = (scaled_width, scaled_height)
 
         return config
@@ -579,8 +803,12 @@ class ScreenshotGenerator:
         """Map device names to device frame names."""
         mapping = {
             "iPhone 15 Pro Portrait": "iPhone 15 Pro - Natural Titanium - Portrait",
-            "iPhone 15 Pro Max Portrait": "iPhone 15 Pro Max - Natural Titanium - Portrait",
+            "iPhone 15 Pro Max Portrait": (
+                "iPhone 15 Pro Max - Natural Titanium - Portrait"
+            ),
             "iPhone 16 Pro Portrait": "iPhone 16 Pro - Natural Titanium - Portrait",
-            "iPhone 16 Pro Max Portrait": "iPhone 16 Pro Max - Natural Titanium - Portrait",
+            "iPhone 16 Pro Max Portrait": (
+                "iPhone 16 Pro Max - Natural Titanium - Portrait"
+            ),
         }
         return mapping.get(device, "iPhone 15 Pro - Natural Titanium - Portrait")
